==> xT4aD___2022-12-16_02-38-05.zip: assets/js/mailer.js <==
var formContacts = document.getElementsByClassName("contactForm");

Array.from(formContacts).forEach((contactForm) => {

var formData = new FormData();
var elements = Array.from(contactForm.elements);

	contactForm.addEventListener("submit", function(event) {
		event.preventDefault();

		var formData = new FormData();
		var elements = Array.from(contactForm.elements);

		for (const element of elements) {
			const valueOfInput = formData.append(element.getAttribute("name"), element.value);
		}

		grecaptcha.ready(function() {
			grecaptcha.execute('6LdMLa4cAAAAALe3fZb0afV_C_TMjLxsMwqDqD_l', {action:'submit'}).then(function(token) {

				formData.append('wa-recaptcha', token);

				var req = new XMLHttpRequest();
				req.open('POST', 'https://mailer.apps.webarray.com/post/HOvoMpaz5gZPEKZ5e2Zfapn6AcJ6l9yk', false);
				
				req.onreadystatechange = function() {
					if (this.readyState === XMLHttpRequest.DONE && this.status === 200) {
						const applicationForm = document.getElementById('applicationForm');
						const quoteForm = document.getElementById('quoteForm')
						if(applicationForm) {
							Swal.fire({
								html: '<h2 class="fw-bolder mb-2">Thank You For Your Application!</h2>' +
								'<p class="mb-0">We are thrilled that you are interested in joining our team. We will review your submission and reach out if we think we would be a great fit for one another.</p>',	
								confirmButtonColor: '#E90A8A',				
							});
						} else if(quoteForm) {
							Swal.fire({
								html: '<h2 class="fw-bolder mb-2">Thank You for Requesting a Quote</h2>' +
								'<p class="mb-0">A member of our team will review your information and reach out with a quote.</p>',	
								confirmButtonColor: '#E90A8A',				
							});
						}

						else {
							Swal.fire({
								html: '<h2 class="fw-bolder mb-2">Thank You For Contacting Us!</h2>' +
								'<p class="mb-0">Your message has been submitted. A member of our team will be in touch.</p>',	
								confirmButtonColor: '#E90A8A',				
							});
							
						}
						//window.location.href = 'https://lidiap.buildmy.ca/private/webarray/magneta-website/2022-08-10MagentaChanges/thankyou.html';			
									
					}	
					else {
						Swal.fire({
							icon: 'error',
							title: 'Oops...',
							text: 'Something went wrong!'
						})
					}
				}
				
				req.send(formData);
							

			});
		});
	});
});

==> xT4aD___2022-12-16_02-38-37.zip: assets/js/mailer.js <==
var formContacts = document.getElementsByClassName("contactForm");

Array.from(formContacts).forEach((contactForm) => {

var formData = new FormData();
var elements = Array.from(contactForm.elements);

	contactForm.addEventListener("submit", function(event) {
		event.preventDefault();

		var formData = new FormData();
		var elements = Array.from(contactForm.elements);

		for (const element of elements) {
			const valueOfInput = formData.append(element.getAttribute("name"), element.value);
		}

		grecaptcha.ready(function() {
			grecaptcha.execute('6LdMLa4cAAAAALe3fZb0afV_C_TMjLxsMwqDqD_l', {action:'submit'}).then(function(token) {

				formData.append('wa-recaptcha', token);

				var req = new XMLHttpRequest();
				req.open('POST', 'https://mailer.apps.webarray.com/post/HOvoMpaz5gZPEKZ5e2Zfapn6AcJ6l9yk', false);
				
				req.onreadystatechange = function() {
					if (this.readyState === XMLHttpRequest.DONE && this.status === 200) {
						const applicationForm = document.getElementById('applicationForm');
						const quoteForm = document.getElementById('quoteForm')
						if(applicationForm) {
							Swal.fire({
								html: '<h4 class="fw-bolder mb-3">Thank You for Your Application!</h4>' +
								'<p class="mb-0">We are thrilled that you are interested in joining our team. We will review your submission and reach out if we think we would be a great fit for one another.</p>',	
								confirmButtonColor: '#E90A8A',				
							});
						} else if(quoteForm) {
							Swal.fire({
								html: '<h4 class="fw-bolder mb-3">Thank You for Requesting a Quote</h4>' +
								'<p class="mb-0">A member of our team will review your information and reach out with a quote.</p>',	
								confirmButtonColor: '#E90A8A',				
							});
						}

						else {
							Swal.fire({
								html: '<h4 class="fw-bolder mb-3">Thank You for Contacting Us!</h4>' +
								'<p class="mb-0">Your message has been submitted. A member of our team will be in touch.</p>',	
								confirmButtonColor: '#E90A8A',				
							});
							
						}			
									
					}	
					else {
						Swal.fire({
							icon: 'error',
							title: 'Oops...',
							text: 'Something went wrong!'
						})
					}
				}
				
				req.send(formData);
							

			});
		});
	});
});
